# Grundlagen

In diesem Kapitel erklären wir die Grundlagen des Laserschneidens bzw. -gravierens und die Funktionen der von uns eingesetzten Lasercutter-Geräte.


## Die verschiedenen Laser im Überblick

Der Lasercutter hat zwei Laser. Es gibt einen roten Punkt ("Laserpointer"), der weitestgehend harmlos ist (nicht in den Strahl blicken, Vorsicht bei Spiegeln im Laser!), welcher auch bei geöffnetem Deckel funktioniert. Dieser wird zur Einrichtung des Materials und zum Testen des Programms verwendet.

Der eigentliche Laser, ein Infrarotlaser mit hoher Leistung, wird sofort abgeschaltet, wenn die Schutzscheibe oder seitliche Klappen geöffnet werden. Von ihm geht keine Gefahr aus, solange die Schutzeinrichtungen funktionieren und nicht manipuliert werden (z.B. durch Magnete in Nähe).

**Magnete innerhalb und außerhalb des Lasers sind absolut untersagt. Es gilt ein Sicherheitsabstand von 50cm!**


## Bearbeitungsmöglichkeiten

Lasercutter folgen entweder sogenannten Vektoren, d.h. sie fahren entlang der in der Eingabedatei vorhandenen Pfade, oder sie rastern (für Gravuren). Die verschiedenen Verfahren werden in diesem Abschnitt vorgestellt.


### Vektormodus

Vektorfahrten dienen dem Schneiden oder Markieren des zu bearbeitenden Materials. Das Markieren wird mit geringsten Leistungen (gerade so viel, damit der Laser eine Spur hinterlässt) bei maximaler Geschwindigkeit durchgeführt. Beim Schneiden wird mit einer auf das Material abgestimmten Leistung und Geschwindigkeit gearbeitet.

Der Laser folgt hierbei den in der Ausgangsdatei angelegten Pfaden. Der Lasercutter ist wie die meisten CNC-gesteuerten Geräte "dumm": Doppelte Linien werden beispielsweise auch doppelt geschnitten. Sollten sich Linien nicht exakt treffen, bleibt dort Material stehen. Sollten die Parameter zu stark gewählt sein, werden die Schnittkannten über die Maßen verbrannnt oder es bilden sich sogar Flammen und versauen die Oberfläche. Sollten die Parameter zu schwach gewählt sein, wird das Material (stellenweise oder gänzlich) nicht durchtrennt. Ein weiterer Durchgang kann notwendig sein, dies ist jedoch nicht zu empfehlen (TODO Link auf FAQ).

Für die meisten Materialien gibt es bereits Voreinstellungen, die regelmäßig aktualisiert werden. Weitere Informationen hierzu im TODO Link auf "Job senden".


### Rastermodus 

Im Rastermodus wird die Eingabegrafik auf das Material "gerastert". Genau wie bei Raster- oder "Pixel"grafiken wird das Bild in eine Abfolge von einzelnen Punkten nach dem vorgegebenen DPI-Wert aufgelöst. DPI steht für "Dots per Inch", also "Punkte pro Zoll", und ist ein in der Grafik und im Druck gebräuchliches Maß für die Auflösung einer Grafik.

- **Epilog Zing 24:** unterstützt laut Handbuch zwischen 100 und 1000 DPI.

Unsere Voreinstellungen bieten drei verschiedene Auflösungen an:

- **grob**: 100 DPI, zum schnellen Testen eines Entwurfs, schnellste Einstellung
- **standard**: 250 DPI, auf Holz nicht von feineren Auflösungen zu unterscheiden
- **extra fein**: 500 DPI, macht nur auf Materialien wie z.B. Glas einen Unterschied und auch nur auf kürzester Distanz

Zum Vergleich: Druckereien verwenden im Regelfall 300 DPI auf Papier für Werbematerialien wie Plakate und Flyer. Große Werbeartikel wie z.B. Banner werden mit 150 DPI gefertigt. Sehr große Materialien wie z.B. Gerüstplanen werden teilweise noch deutlich "grober" gefertigt!

Vektoren werden beim Vorbereiten für das Lasern (siehe TODO Kapitel) automatisch gerastert, sofern sie graviert und nicht geschnitten/markiert werden.

Bitte beachte, dass z.B. das Markieren für dünn(s)te Linien viel besser geeignet ist und auch schneller geht als eine Gravur.

**Hinweis: Jobs im Rastermodus dauert im Regelfall sehr lange. Bitte plane genug Zeit ein!** Falls du sehr viel zu lasern hast, lasse bitte andere Besucher:innen zwischendurch an das Gerät!

Im Rastermodus gibt es zwei Modi, die unterschieden werden müssen: die "normale" Gravur und die 3D-Gravur. Während erstere ein sogenanntes Dithering-Verfahren verwendet und bei gleichbleibender Laserleistung mehr oder weniger Punkte setzt, um verschiedene Graustufen abzubilden, wird bei der 3D-Gravur die Leistung in helleren Bereichen reduziert.


#### "Normale" Gravur (mit Dithering)

Bei der "normalen" Gravur wird die Helligkeit jedes einzelnen Pixels berechnet, der in der Eingabegrafik vorhanden ist. Durch Anwendung eines [Dithering-Verfahrens](https://de.wikipedia.org/wiki/Dithering_(Bildbearbeitung)) wird das Bild in eine Schwarz-Weiß-Repräsentation umgerechnet, da der Lasercutter in diesem Modus entweder gar nicht oder mit der eingestellten Leistung arbeitet. Um die entsprechende Helligkeit der Grafik im Material wiederzugeben, berechnet der Dithering-Algorithmus eine Abfolge von Punkten mit voller Leistung und ohne Aktion, die dieser gerecht wird. Ein einfaches Dithering-Verfahren würde z.B. bei 50 Prozent Helligkeit jeden zweiten Punkt setzen.

Die von uns verwendete Software [VisiCut](https://visicut.org) bietet verschiedene Dithering-Verfahren an, von sehr einfachen bis hin zu ausgefeilten Verfahren wie dem [Floyd-Steinberg-Algorithmus](https://de.wikipedia.org/wiki/Floyd-Steinberg-Algorithmus). Diese werden in den folgenden Grafiken illustriert:

![Vergleich verschiedener Dithering-Algorithmen am Beispiel von Michelangelos Statue des David](./images/dithering-david.png)

Am Beispiel von Michelangelos David zeigt die obige Grafik einige Dithering-Verfahren, die jeweils unterschiedliche Ergebnisse erzeugen (Afrank99, M.G.Berberich, lizenziert unter der *CC-By-SA 3.0 unported*).

![Verschiedene Halbtonverfahren, links das Ausgangsbild, in der Mitte ein 8×8-Halbtonraster, rechts Fehlerverteilungsalgorithmus nach Stucki](./images/dithering-vollton-halbton-stucki.png)

In dieser Grafik werden verschiedene Halbtonverfahren gezeigt: links das Original, in der Mitte ein Halbtonraster, rechts der Stucki-Algorithmus (ein auf dem Floyd-Steinberg-Algorithmus aufbauendes Verfahren).

*Der Druckertreiber des Herstellers, der von uns zur Steuerung _nicht_ eingesetzt und nicht empfohlen wird, bietet zwei Verfahren an, ein unbekantes namens "Standard" und den Stucki-Algorithmus.*

Die Gravurgeschwindigkeit wird nicht variiert und bleibt während des gesamten Vorgangs gleich.


#### 3D-Gravur

Bei der 3D-Gravur wird die Helligkeit jedes einzelnen Pixels berechnet, der zu gravieren ist. Diese Helligkeit wird in eine Laserleistung relativ zur eingestellten Maximalleistung umgerechnet. Der Lasercutter graviert demnach mit sich kontinuierlich ändernden Leistungen. Dies sorgt für einen dreidimensionalen Effekt, da jeder Pixel unterschiedlich tief graviert wird. Je nach Material ist dieser Effekt stärker oder schwächer.

Die Gravurgeschwindigkeit wird nicht variiert und bleibt während des gesamten Vorgangs gleich.






