# Job erstellen und senden

Wir nutzen zur Erstellung der Laser-Jobs die Software [VisiCut](https://visicut.org), die auch in vielen anderen FabLabs im Einsatz ist. Sie wurde explizit für diese Aufgabe entwickelt und die Benutzerschnittstelle ist extra darauf ausgerichtet.

Standardmäßig nutzen die meisten Laser-Cutter reguläre Druckertreiber, die bestimmte Farben als Vektor- und Rasterfahrten erkennen. Diese sind sehr viel eingeschränkter nutzbar und meist auf proprietäre Betriebssysteme wie Microsoft Windows limitiert. VisiCut bietet eine weitaus größere Flexibilität und kann nicht nur verschiedene Farben in verschiedene Verfahren übersetzen, auch eine Unterscheidung z.B. nach Ebenenen ist möglich.

Im folgenden Abschnitt erklären wir die Grundzüge der Verwendung von VisiCut.


## Job in VisiCut öffnen

Dokumente werden mittels der im vorherigen Abschnitt TODO vorgestellten Inkscape-Erweiterung an VisiCut geschickt.

**Wir raten davon ab, (SVG-)Dateien direkt in VisiCut zu öffnen!** Das Inkscape-Plugin konvertiert Eingabedateien zunächst in ein einfaches, geometrisch bestimmtes Format. Texte und Objekte wie Ellipsen oder Vielecke, die SVG nicht direkt unterstützt und die Inkscape als "Erweiterung" in der SVG-Datei speichert, werden automatisch in Pfade konvertiert.


## Grundeinstellungen (für erfahrene Benutzer)

- Um ein gutes Ergebnis beim Ausschneiden zu erhalten, ist es nötig, dass genug Rand übrig ist, um das Objekt auch ausschneiden zu können. Das Objekt sollte in VisiCut immer einige Millimeter vom Rand wegbewegt werden. Achte auf Ausfransungen vom Zuschnnitt der Platten!
- Immer daran denken, dass das Lineal am Wabentisch nicht laserfest ist! Lieber einige Millimeter Abstand hierzu lassen, indem das zu lasernde Material in VisiCut vom Rand weggeschoben wird! (Siehe auch TODO Mapping)
- Nutze das Standardmapping, so viel es geht! Lege deine Dateien in den Farben rot, grün, blau an!
- Den besten Kontrast beim Gravieren erreichts du mit Vollfarben bzw. einem vollen Schwarzton!


## Übersicht über VisiCut-Benutzerschnittstelle

![Beispiel eines in VisiCut geöffneten Projekts](images/visicut-übersicht.png)

Das obige Bildschirmfoto zeigt die VisiCut-Benutzerschnittstelle, in der eine Beispieldatei geöffnet wurde. Einige Elemente wurden mit Ziffern hervorgehoben:

1. In der "Vorschau" werden die geöffneten Dateien gezeigt. Sie besitzt die Größe der Laserfläche, um die Positionierung zu erleichtern.

   Vektorfahrten werden rot gezeigt, Gravuren schwarz bzw. in Graustufen. Die Farben werden erst so anngepasst, nachdem ein Mapping ausgewählt wurde (siehe Ziffer 6).

2. In dieser Liste finden sich die verschiedenen Lasercutter. Sobald mehr als ein Laser vorhanden ist, muss der passende hier zunächst ausgewählt werden.

3. In der Materialliste finden sich Voreinstellungen für die gängigsten Materialien. Insbesondere die von uns verkauften Materialien sind hier zu finden.

   Die Werte müssen regelmäßig angepasst werden, da die Leistung des Lasers nicht konstant ist, sondern von verschiedenen Faktoren abhängt (z.B. das Alter der Röhre, die Verschmutzung der Optik, ...). Während der Maschinenwartung werden diese regelmäßig aktualisiert.

4. Die Dicke oder "Stärke" des eingelegten Materials. Da beim Schneiden der Fokus in die Mitte des Materials gelegt werden soll, ist es wichtig, die Materialstärke korrekt anzugeben.

   VisiCut berechnet nicht automatisch den Fokus von Schnitten, der Wert ist eher kosmetischer Natur. Der Fokus in der Mitte des Materials wird im entsprechenden Laserprofil angegeben.

   Sofern die exakte Materialstärke nicht in der Liste vorhanden ist, ist kein Profil angelegt. Hierbei gelten folgende Grundsätze:

   - Eine etwas dickere Voreinstellung auszuwählen schadet nicht (z.B. 4mm statt 3mm). Beachte: der Fokus beim Schnitt verschiebt sich hierbei. Eine Abweichung von wenigen 10tel Millimetern ist tolerierbar. Da das Material sowieso auf der Oberfläche fokussiert wird, hat die Auswahl der Dicke im Regelfall keinen Einfluss auf diese Werte.

   - Werte sind aufzurunden: 3,7mm können als 4mm betrachtet werden. 4.3mm sollten als 5mm behandelt werden. In der Nähe des Lasercutters sind eine einfache Dickenschablone und ein Messschieber ("Schieblehre") platziert, die die einfache Messung erlauben.

5. Die drei Reiter <kbd>Mapping</kbd>, <kbd>Position</kbd> und <kbd>Laser-Einstellungen</kbd> werden in den nächsten Abschnitten erläutert.

6. Hierbei wird ebenfalls auf die folgenden Abschnitte verwiesen.

7. In diesem Feld kann ein Präfix angegeben werden, das dann auf dem Laser zu lesen ist. Dieses Präfix dient der Unterscheidung verschiedener nacheinander oder parallel geschickter Jobs. Es sollte nicht zu lang sein (idealerweise weniger als 8 Zeichen) und eindeutig zum Benutzer zuzuordnen sein.

   Beispiele:

   - Dein Name ist Maria Musterfrau. Du laserst heute acht Dateien. Dies ist der zweite Versuch der sechsten Datei. Ein gutes Präfix lautet `MM_8_2`.

   - Dein Name ist Franz Bauer und du möchtest schnell etwas testen. Du gehst davon aus, dass du mehrere Jobs abschickenn musst, bis alles passt. Dein Präfix könnte lauten: `Franz_03`.


## Die Reiter <kbd>Mapping</kbd>, <kbd>Position</kbd> und <kbd>Laser-Einstellungen</kbd>

Viele Einstellungen verstecken sich im unteren Bereich der rechten Seitenleiste. Dort finden sich drei Reiter, die im Folgenden vorgestellt werden.


### Reiter <kbd>Mapping</kbd>

Beim Mapping werden den einzelnen grafischen Elementen Laserprofile zugeordnet. Dies geschieht z.B. über die Zuordnung verschiedener Farben, z.B. "rot für Schnitt" oder "gelb für Gravur". Auch möglich ist die Zuordnung verschiedener Gruppen bzw. Ebenen, die Unterscheidung verschiedener Strichbreiten oder der Bezug auf einzelne Objekte durch deren Objekt-ID in der SVG-Datenstruktur.

![Auswahlmöglichkeiten Drop-Down-Menü Mapping in VisiCut](images/visicut-mapping.png)

Standardmäßig unterscheiden wir nach Strich- und Füllfarben. Das Standardprofil heißt <kbd>schneide rot, markiere grün, ignoriere blau, graviere Rest</kbd>:

- rote Linien (bzw. Konturen von Pfaden) werden mit entsprechend hoher Leistung geschnitten (rote Füllungen werden ignoriert)
- grüne Linien (bzw. Konturen von Pfaden) werden mit niedriger Leistung markiert (grüne Füllungen werden ignoriert)
- blaue Elemente werden ignoriert (z.B. Kommentare oder Hilfslinien, die zur Positionierung genutzt werden)
- alles andere wird graviert

Alternativ können alle Elemente einem dieser Profile zugeordnet werden, was für einfache Aufgaben oft ausreicht.

Die einzelnen Profile werden im Abschnitt TODO Laserprofile erläutert.

Um eigene Einstellungen vorzunehmen, empfehlen wir, das Standardprofil auszuwählen und dann den Bleistiftknopf zu drücken. Dort können die Zuordnungen dann angepasst werden.

![Benutzerdefiniertes Mapping in VisiCut](images/visicut-mapping-benutzerdefiniert.png)

Die Bedienung ist einigermaßen selbsterklärend und die Möglichkeiten sind zu umfangreich, um sie an dieser Stelle zu erklären. Erfahrenen Benutzern wird empfohlen, sich hiermit selbstständig zu beschäftigen.


### Reiter <kbd>Position</kbd>

In diesem Reiter können die Position und die Größe des zu lasernden Objekts exakt eingestellt werden.

![Positionseinstellungen in VisiCut](images/visicut-position.png)

Die Position des zu lasernden Objekts wird vom Referenzpunkt aus relativ zum Koordinatenursprung angegeben.

- *Epilog Zing 24:* Standardmäßig befindet sich der Koordinatenursprung in der hinteren linken Ecke. *(Dort ist der Laser auch am Stärksten.)*

Der Referenzpunkt kann in VisiCut frei gewählt werden. Dies kann nützlich sein, um die Positionierung zu anderen Objekten im Tisch zu vereinfachen. **Dies ist nur für erfahrene Benutzer gedacht!** Soweit möglich, lasse die Voreinstellung "oben links" so stehen.

Du kannst die Position auf dem Wabentisch anhand der Skalen grob abschätzen oder ein Lineal oder einen Meterstab zur Positionierung relativ zur linken hinteren Ecke des Anschlags im Laser nutzen.

Die `x`- und `y`-Werte geben die Abstände des Referenzpunkts relativ zum Koordinatenursprung exakt an.

Die Breite und Höhe des Objekts können hier ebenfalls noch einmal eingestellt werden. Mit Klick auf <kbd>proportional</kbd> wird der jeweils andere Wert automatisch angepasst, wenn einer der Werte geändert wird. Auch der Winkel kann frei eingestellt werden.

Falls das Objekt beim Laden zu groß ist, wird es auf die Laserflache proportional verkleinert.

**Hinweis: es ist sinnvoller, die Größe und den Winkel bereits in Inkscape korrekt anzulegen, da die Änderungen dort in einer SVG-Datei gespeichert werden können!** VisiCut-Projekte können zwar gespeichert werden, es besteht aber die reale Möglichkeit, dass das Objekt nicht mehr geladen werden kann. Außerdem bietet Inkscape viel mehr Möglichkeiten, Maße später wieder abzulesen oder anzupassen. Die Einstellungen in Inkscape sollten als **Notlösung** betrachtet werden!


### Reiter <kbd>Laser-Einstellungen</kbd>

In diesem Reiter werden die Laser-Einstellungen vorgenommen: nicht nur die Leistung und Geschwindigkeit, auch das Verhalten kann hier konfiguriert werden.

**Bei Nutzung der Materialvoreinstellungen ist hier im Regelfall nichts weiter einzustellen.** Nur bei Problemen (z.B. "Laser schneidet nicht ganz durch") müssen die Werte hier ggf. angepasst werden. **Sofern die Leistung nicht ausreicht, ist es aber erst sinnvoller, den Laser zu reinigen!** Sprich hierzu bitte mit den Betreuern, die das ggf. an die Maschinenbetreuer weitergeben.

Die hier gezeigten Einstellmöglichkeiten hängen von zwei Faktoren ab: das <kbd>Mapping</kbd> gibt die möglichen Profile vor, die angezeigt werden können. Diese werden aber auch nur dann angezeigt, wenn entsprechende Elemente in der Datei vorkommen.

![Benutzerdefiniertes Mapping in VisiCut](images/visicut-laser-einstellungen.png)

TODO: Bild aktualisieren, Gravureinstellungen fein -> Standard

*Beispiel: das geladene Dokument enthält jeweils einen Text mit schwarzer Füllung und eine dünne rote Randlinie zum Ausschneiden. Es wurde das Standardprofil <kbd>schneide rot, markiere grün, ignoriere blau, graviere Rest</kbd> gewählt. In der Liste werden die Einstellungen "gravieren (Standard) (Alles andere)" und "schneiden (Farbe rot)" gezeigt.*

Je nachdem, ob es sich bei dem jeweiligen Profil um eine Raster- oder Vektorfahrt handelt, unterscheiden sich die Auswahlmöglichkeiten:

- Bei **Rasterfahrten** können **"power"**, **"speed"**, **"focus"** und **"bottom up"** konfiguriert werden. "power" und "speed" sind selbsterkärend, die Werte werden in Prozent angegeben. Der Fokus sollte `0` betragen, da sowieso immer auf die Oberfläche das Materials fokussiert wird. "bottom up" sorgt dafür, dass von unten nach oben graviert wird, was verhindert, dass der Abtrag und etwaige Rauchgase sich nicht in der frischen Gravur niederschlagen.
- Bei **Vektorfahrten** können **"power"**, **"speed"**, **"focus"** und **"frequency"** konfiguriert werden. "power" und "speed" sind selbsterkärend, die Werte werden in Prozent angegeben. Der Fokus sollte in der Mitte des Materials liegen, hierzu **negative Werte** eingeben. Die Frequenz kann auf dem Maximalwert `5000` stehen bleiben.

Sofern in der Liste Werte wie "power" oder "speed" auf `0` stehen, ist vermutlich kein Vorgabewert vorhanden. In diesem Fall muss das Material kalibriert werden. Hierzu siehe Abschnitt TODO Material einstellen.



## Laserprofile













